Class "buhlmannStraub" of fitted Buhlmann-Straub credibility models
buhlmannStraub-class.RdClass "buhlmannStraub" of fitted Buhlmann-Straub credibility models
Arguments
- object
an object of class
buhlmannStraub- newdata
optionally, a data frame in which to look for variables with which to predict.
- ...
currently ignored.
- x
an object of class
buhlmannStraub
Value
The function buhlmannStraub returns an object of class buhlmannStraub, which has the following slots:
- call
the matched call
- type
Whether additive or multiplicative credibility model is used.
- Variances
The estimated variance components.
Sigmais the estimated within-group variance (process variance), andTauis the estimate of the between-group variance (variance of the hypothetical means).- Means
The estimated averages at the portfolio level (collective premium \(\mu\)) and at the cluster level (weighted average \(\bar{Y}_j\)).
- Weights
The total weights \(w_j\) for each cluster.
- Credibility
The credibility factors \(z_j\) for each cluster.
- Premiums
The collective premium \(\hat{\mu}\) and individual premiums \(\hat{V}_j\) for each cluster.
- Relativity
The estimated random effects \(\hat{U}_j\) of each cluster.
- RawResults
Object of type
data.tablewith all intermediate results.- fitted.values
the fitted mean values, resulting from the model fit.
S3 methods
print:Prints the
call, the estimated variance parameters and the unique number of clusters. The...argument is currently ignored. Returns an invisible copy of the original object.summary:In addition to the output of the
print.buhlmannStraubfunction, thesummaryfunction prints the cluster-level estimates as well. Returns an invisible copy of the original object.fitted:Returns the fitted values.